@@ -19,7 +19,7 @@ public:
 protected:
 	void closeEvent(QCloseEvent* event) override;
 
-private slots:
+private Q_SLOTS:
 	void setLocale();
 	void about();
 };
