@@ -16,7 +16,7 @@
     <name>LocaleDialog</name>
     <message>
         <source>Select application language:</source>
-        <translation>Taal selecteren:</translation>
+        <translation>Kies de programmataal:</translation>
     </message>
     <message>
         <source>&lt;System Language&gt;</source>
@@ -28,7 +28,7 @@
     </message>
     <message>
         <source>Please restart this application for the change in language to take effect.</source>
-        <translation>Herstart de applicatie om de taalwijziging toe te passen.</translation>
+        <translation>Herstart het programma om de taalwijziging toe te passen.</translation>
     </message>
 </context>
 <context>
@@ -43,7 +43,7 @@
     </message>
     <message>
         <source>Unable to load previous game. Starting a new game.</source>
-        <translation>Het vorige spel kan niet worden geladen; start een nieuw spel.</translation>
+        <translation>Het vorige spel kan niet worden geladen - start een nieuw spel.</translation>
     </message>
 </context>
 <context>
@@ -70,7 +70,7 @@
     </message>
     <message>
         <source>Application &amp;Language...</source>
-        <translation>Applicatietaa&amp;l...</translation>
+        <translation>Programmataa&amp;l…</translation>
     </message>
     <message>
         <source>&amp;Help</source>
@@ -94,7 +94,7 @@
     </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
-        <translation>Auteursrecht &amp;copie; 2009-%1 Graeme Gott</translation>
+        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
     </message>
     <message>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
